Learn R Programming

gutenbergr (version 0.1.1)

gutenberg_authors: Metadata about Project Gutenberg authors

Description

Data frame with metadata about each author of a Project Gutenberg work. Although the Project Gutenberg raw data also includes metadata on contributors, editors, illustrators, etc., this dataset contains only people who have been the single author of at least one work.

Usage

gutenberg_authors

Arguments

Details

To find the date on which this metadata was last updated, run attr(gutenberg_authors, "date_updated").

See Also

gutenberg_metadata, gutenberg_subjects

Examples

Run this code
# date last updated
attr(gutenberg_authors, "date_updated")

Run the code above in your browser using DataLab