Learn R Programming

gutenbergr (version 0.4.0)

gutenberg_cache_clear_all: Clear all files from the Gutenberg cache

Description

Deletes all cached .rds files in the directory currently returned by gutenberg_cache_dir().

Usage

gutenberg_cache_clear_all(verbose = TRUE)

Value

The number of files deleted (invisibly).

Arguments

verbose

Whether to show the status message confirming the path.

Examples

Run this code
if (FALSE) { # interactive()
# Clear entire current cache
gutenberg_cache_clear_all()
}

Run the code above in your browser using DataLab