View source: R/gutenberg_cache.R
| gutenberg_cache_dir | R Documentation |
Calculates the path to the directory where Gutenberg files are stored,
based on the current gutenbergr_cache_type and gutenbergr_base_cache_dir
options.
gutenberg_cache_dir()
A character string representing the path to the cache directory.
The following options control caching behavior:
gutenbergr_cache_type: Character string indicating how downloaded works
are cached. Must be either "session" (default) or "persistent".
gutenbergr_base_cache_dir: Base directory used for persistent caching when
gutenbergr_cache_type = "persistent".
By default, this is an OS-specific cache directory determined by
tools::R_user_dir("gutenbergr", "cache"). Advanced users may set this
to a custom path.
# Get current cache directory
gutenberg_cache_dir()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.