gutenberg_cache_list: List files in the Gutenberg cache

View source: R/gutenberg_cache.R

gutenberg_cache_listR Documentation

List files in the Gutenberg cache

Description

Provides a detailed list of files currently stored in the directory returned by gutenberg_cache_dir().

Usage

gutenberg_cache_list(verbose = TRUE)

Arguments

verbose

Whether to show the status message showing the cache directory path.

Value

A tibble::tibble() with the following columns:

title

The title of the work.

author

The author(s) of the work.

file

The filename.

size_mb

Size of the file in megabytes.

modified

The last modification time.

path

The file's absolute path.

Examples


# List all works in the currently set cache
gutenberg_cache_list()

# Suppress the directory path message
gutenberg_cache_list(verbose = FALSE)


gutenbergr documentation built on Jan. 19, 2026, 9:07 a.m.