Ensure the Gutenberg cache directory exists
Source:R/gutenberg_cache.R
gutenberg_ensure_cache_dir.RdChecks for the existence of the cache directory and creates it if it is missing.

R/gutenberg_cache.R
gutenberg_ensure_cache_dir.RdChecks for the existence of the cache directory and creates it if it is missing.