View source: R/gutenberg_mirrors.R
| gutenberg_get_all_mirrors | R Documentation |
Get all mirror data from https://www.gutenberg.org/MIRRORS.ALL. This only includes mirrors reported to Project Gutenberg and verified to be relatively stable. For more information on mirroring and getting your own mirror listed, see https://www.gutenberg.org/help/mirroring.html.
gutenberg_get_all_mirrors()
A tibble::tibble() of Project Gutenberg mirrors and related data,
or NULL (invisibly) if the mirror list cannot be retrieved or parsed.
If a tibble::tibble() is returned, it contains:
Continent where the mirror is located
Nation where the mirror is located
Location of the mirror
Provider of the mirror
URL of the mirror
Special notes
gutenberg_get_all_mirrors()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.