gutenberg_get_mirror: Get the recommended mirror for Gutenberg files

View source: R/gutenberg_mirrors.R

gutenberg_get_mirrorR Documentation

Get the recommended mirror for Gutenberg files

Description

Get the recommended mirror for Gutenberg files and set the global gutenberg_mirror option.

Usage

gutenberg_get_mirror(verbose = TRUE)

Arguments

verbose

Whether to show messages about the Project Gutenberg mirror that was chosen.

Value

A character vector with the URL for the chosen mirror.

Examples


gutenberg_get_mirror()


gutenbergr documentation built on Jan. 19, 2026, 9:07 a.m.