| gutenberg_languages | R Documentation |
Data frame with metadata about the languages of each Project Gutenberg work.
gutenberg_languages
A tibble::tibble() with one row for each
work-language pair, with the columns:
Unique identifier for the work that can be used to join with the gutenberg_metadata dataset
Language ISO 639 code. Two letter code if one exists, otherwise three letter.
Number of languages for this work.
To find the date on which this metadata was last updated,
run attr(gutenberg_languages, "date_updated").
gutenberg_metadata, gutenberg_subjects
# See date last updated
attr(gutenberg_languages, "date_updated")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.