Learn R Programming

gutenbergr (version 0.4.0)

gutenbergr-package: gutenbergr: Download and Process Public Domain Works from Project Gutenberg

Description

Download and process public domain works in the Project Gutenberg collection https://www.gutenberg.org/. Includes metadata for all Project Gutenberg works, so that they can be searched and retrieved.

Arguments

Author

Maintainer: Jordan Bradford jrdnbradford@gmail.com (ORCID)

Authors:

See Also