powered by
Deletes all cached .rds files in the directory currently returned by gutenberg_cache_dir().
.rds
gutenberg_cache_dir()
gutenberg_cache_clear_all(verbose = TRUE)
The number of files deleted (invisibly).
Whether to show the status message confirming the path.
if (FALSE) { # interactive() # Clear entire current cache gutenberg_cache_clear_all() }
Run the code above in your browser using DataLab