View source: R/gutenberg_cache.R
| gutenberg_cache_list | R Documentation |
Provides a detailed list of files currently stored in the directory
returned by gutenberg_cache_dir().
gutenberg_cache_list(verbose = TRUE)
verbose |
Whether to show the status message showing the cache directory path. |
A tibble::tibble() with the following columns:
The title of the work.
The author(s) of the work.
The filename.
Size of the file in megabytes.
The last modification time.
The file's absolute path.
# List all works in the currently set cache
gutenberg_cache_list()
# Suppress the directory path message
gutenberg_cache_list(verbose = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.