powered by
Get all mirror data from https://www.gutenberg.org/MIRRORS.ALL. This only includes mirrors reported to Project Gutenberg and verified to be relatively stable. For more information on mirroring and getting your own mirror listed, see https://www.gutenberg.org/help/mirroring.html.
gutenberg_get_all_mirrors()
A tibble::tibble() of Project Gutenberg mirrors and related data:
tibble::tibble()
Continent where the mirror is located
Nation where the mirror is located
Location of the mirror
Provider of the mirror
URL of the mirror
Special notes
if (FALSE) { # interactive() gutenberg_get_all_mirrors() }
Run the code above in your browser using DataLab