Learn R Programming

gutenbergr (version 0.4.0)

gutenberg_get_mirror: Get the recommended mirror for Gutenberg files

Description

Get the recommended mirror for Gutenberg files and set the global gutenberg_mirror option.

Usage

gutenberg_get_mirror(verbose = TRUE)

Value

A character vector with the URL for the chosen mirror.

Arguments

verbose

Whether to show messages about the Project Gutenberg mirror that was chosen.

Examples

Run this code
if (FALSE) { # interactive()
gutenberg_get_mirror()
}

Run the code above in your browser using DataLab