Learn R Programming

gutenbergr (version 0.1.1)

gutenberg_works: Get a filtered table of Gutenberg work metadata

Description

Get a table of Gutenberg work metadata that has been filtered by some common (settable) defaults, along with the option to add additional filters. This function is for convenience when working with common conditions when pulling a set of books to analyze. For more detailed filtering of the entire Project Gutenberg metadata, use the gutenberg_metadata and related datasets.

Usage

gutenberg_works(..., languages = "en", only_text = TRUE,
  rights = c("Public domain in the USA.", "None"), distinct = TRUE,
  all_languages = FALSE, only_languages = TRUE)

Arguments

...
Additional filters, given as expressions using the variables in the gutenberg_metadata dataset (e.g. author == "Austen, Jane")
languages
Vector of languages to include
only_text
Whether the works must have Gutenberg text attached. Works without text (e.g. audiobooks) cannot be downloaded with gutenberg_download
rights
Values to allow in the rights field. By default allows public domain in the US or "None", while excluding works under copyright. NULL allows any value of Rights
distinct
Whether to return only one distinct combination of each title and gutenberg_author_id. If multiple occur (that fulfill the other conditions), it uses the one with the lowest ID
all_languages
Whether, if multiple languages are given, all of them need to be present in a work. For example, if c("en", "fr") are given, whether only en/fr as opposed to English or French works should be returned
only_languages
Whether to exclude works that have other languages besides the ones provided. For example, whether to include en/fr when English works are requested

Value

  • A tbl_df (see the tibble or dplyr packages) with one row for each work, in the same format as gutenberg_metadata.

Details

By default, returns

  • English-language works
That are in text format in Gutenberg (as opposed to audio) Whose text is not under copyright At most one distinct field for each title/author pair

Examples

Run this code
library(dplyr)

gutenberg_works()

# filter conditions
gutenberg_works(author == "Shakespeare, William")

# language specifications

gutenberg_works(languages = "es") %>%
  count(language, sort = TRUE)

gutenberg_works(languages = c("en", "es")) %>%
  count(language, sort = TRUE)

gutenberg_works(languages = c("en", "es"), all_languages = TRUE) %>%
  count(language, sort = TRUE)

gutenberg_works(languages = c("en", "es"), only_languages = FALSE) %>%
  count(language, sort = TRUE)

Run the code above in your browser using DataLab